package meerkat.voting.controller.callbacks;

import meerkat.protobuf.Voting.*;
import meerkat.voting.controller.SystemMessages;
import meerkat.voting.controller.commands.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;
import java.util.concurrent.LinkedBlockingQueue;

/**
 * Created by hai on 11/04/16.
 */
public class ChannelChoiceCallback extends ControllerCallback<List<BallotAnswer>> {
    protected final static Logger logger = LoggerFactory.getLogger(ChannelChoiceCallback.class);

    public ChannelChoiceCallback(int requestId,
                                 long ballotSerialNumber,
                                 LinkedBlockingQueue<ControllerCommand> controllerQueue) {
        super(requestId, ballotSerialNumber, controllerQueue);
    }

    @Override
    public void onSuccess(List<BallotAnswer> result) {
        if (result.size() != 0) {
            logger.debug("callback for channel choice returned success");
            enqueueCommand(new ChannelDeterminedCommand(getRequestIdentifier(), getBallotSerialNumber(), result));
        }
        else {
            logger.debug("ChannelChoiceCallback got a cancellation response: " + result);
            enqueueCommand(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
        }
    }

    @Override
    public void onFailure(Throwable t) {
        logger.error("channel choice initiated a failure: " + t);
        enqueueCommand(new ReportErrorCommand(getRequestIdentifier(),
                getBallotSerialNumber(),
                SystemMessages.getUnsuccessfulChannelChoiceMessage()));
    }
}
