package meerkat.voting.storage;

import meerkat.protobuf.Voting.*;

import java.io.IOException;

/**
 * An interface for the storage component of the voting booth
 */
public interface StorageManager {

    /**
     * Detect whether an administration key is inserted to the machine. This determines if we gointo the set-up flow or the voting session flow.
     * @return True is a hardware key is inserted. False if not.
     */
    public boolean isAdminHardwareKeyInserted();

    /**
     * load the election params from the storage.
     * @return the current election params
     * @throws IOException
     */
    public ElectionParams readElectionParams () throws IOException;

    /**
     * write the election parameters protobuf to the storage
     * @param params ElectionParams protobuf to save
     * @throws IOException
     */
    public void writeElectionParams(ElectionParams params) throws IOException;

}
