package meerkat.voting.storage;

import meerkat.protobuf.Voting.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * A mockup for the StorageManager interface
 * Currently keeps the ElectionParams in a file in the user's home-directory
 */
public class StorageManagerMockup implements StorageManager {

    private boolean adminHardwareKeyInserted;
    private Logger logger;
    private String electionParamFullFilename = "~/meerkat_election_params_tempfile.dat";

    public StorageManagerMockup () {
        logger = LoggerFactory.getLogger(StorageManagerMockup.class);
        logger.info("A StorageManagerMockup is constructed");
        this.adminHardwareKeyInserted = false;
    }

    @Override
    public boolean isAdminHardwareKeyInserted() {
        logger.info("Entered method isAdminHardwareKeyInserted");
        logger.warn("isAdminHardwareKeyInserted is not yet fully implemented. It does not check the file system. "
                + "Rather it just returns a private boolean member");
        return adminHardwareKeyInserted;
    }

    @Override
    public ElectionParams readElectionParams() throws IOException {
        logger.info("Entered method readElectionParams");
        ElectionParams params;
        try {
            FileInputStream inputStream = new FileInputStream(electionParamFullFilename);
            params = ElectionParams.parseFrom(inputStream);
            inputStream.close();
            logger.info ("Successfully read election parameter protobuf from a file");
        }
        catch (IOException e) {
            logger.error("Could not read from the election parameter file: '" + electionParamFullFilename + "'.");
            throw e;
        }
        return params;
    }

    @Override
    public void writeElectionParams(ElectionParams params) throws IOException {
        logger.info("Entered method writeElectionParams");
        try {
            FileOutputStream output = new FileOutputStream(electionParamFullFilename);
            params.writeTo(output);
            output.close();
            logger.info ("Successfully wrote election parameter protobuf to a file");
        }
        catch (IOException e) {
            logger.error("Could not write to the election parameter file: '" + electionParamFullFilename + "'.");
            throw e;
        }
    }

}
